@@ -27,16 +27,16 @@ test_that("bilat.symmetry1.works", {
          replicate = mosquito$replicate)
   succeed(mosquito.sym <- bilat.symmetry(A = wingshape, ind = ind, side = side,
          replicate = replicate, object.sym = FALSE, RRPP = TRUE, 
-         iter = 3, data = gdf))
+         iter = 3, data = gdf, print.progress = F))
   succeed(summary(mosquito.sym))
 })
 
 test_that("bilat.symmetry2.works", {
   data(mosquito)
-  Y.gpa <- gpagen(mosquito$wingshape)
+  Y.gpa <- gpagen(mosquito$wingshape, print.progress = F)
   succeed(mosquito.sym2 <- bilat.symmetry(A = Y.gpa, ind = mosquito$ind, 
     side = mosquito$side, replicate = mosquito$replicate, 
-    object.sym = FALSE, RRPP = TRUE, iter = 3))
+    object.sym = FALSE, RRPP = TRUE, iter = 3, print.progress = F))
   succeed(summary(mosquito.sym2))
 })
 
@@ -47,7 +47,7 @@ test_that("bilat.symmetry3.works", {
     replicate = lizards$rep)
   succeed(liz.sym <- bilat.symmetry(A = shape, ind = ind, rep = rep, 
     object.sym = TRUE, land.pairs = lizards$lm.pairs, 
-    iter = 3, data = gdf, RRPP = TRUE))
+    iter = 3, data = gdf, RRPP = TRUE, print.progress = F))
   succeed(summary(liz.sym))
 })
 
@@ -56,7 +56,8 @@ test_that("bilat.symmetry4.works", {
   gdf <- geomorph.data.frame(shape = scallops$coorddata, ind = scallops$ind)
   succeed(scallop.sym <- bilat.symmetry(A = shape, ind = ind, 
     object.sym = TRUE, curves= scallops$curvslide, surfaces = scallops$surfslide,
-    land.pairs=scallops$land.pairs, iter = 3, data = gdf, RRPP = TRUE))
+    land.pairs=scallops$land.pairs, iter = 3, data = gdf, RRPP = TRUE, 
+         print.progress = F))
   succeed(summary(scallop.sym))
 })
 
@@ -64,8 +65,10 @@ test_that("bilat.symmetry4.works", {
 
 test_that("combine.subsets1.works", {
   data(larvalMorph) 
-  head.gpa <- gpagen(larvalMorph$headcoords, curves = larvalMorph$head.sliders)
-  tail.gpa <- gpagen(larvalMorph$tailcoords, curves = larvalMorph$tail.sliders)
+  head.gpa <- gpagen(larvalMorph$headcoords, curves = larvalMorph$head.sliders, 
+                     print.progress = F)
+  tail.gpa <- gpagen(larvalMorph$tailcoords, curves = larvalMorph$tail.sliders, 
+                     print.progress = F)
   succeed(all.lm <- combine.subsets(head = larvalMorph$headcoords,
     tail = larvalMorph$tailcoords, gpa = FALSE, CS.sets = NULL))
   succeed(plotAllSpecimens(all.lm$coords))
@@ -73,16 +76,20 @@ test_that("combine.subsets1.works", {
 
 test_that("combine.subsets2.works", {
   data(larvalMorph) 
-  head.gpa <- gpagen(larvalMorph$headcoords, curves = larvalMorph$head.sliders)
-  tail.gpa <- gpagen(larvalMorph$tailcoords, curves = larvalMorph$tail.sliders)
+  head.gpa <- gpagen(larvalMorph$headcoords, curves = larvalMorph$head.sliders, 
+                     print.progress = F)
+  tail.gpa <- gpagen(larvalMorph$tailcoords, curves = larvalMorph$tail.sliders, 
+                     print.progress = F)
   succeed(comb.lm <- combine.subsets(head = head.gpa, tail = tail.gpa, gpa = TRUE))
   succeed(comb.lm)
 })
 
 test_that("combine.subsets3.works", {
   data(larvalMorph) 
-  head.gpa <- gpagen(larvalMorph$headcoords, curves = larvalMorph$head.sliders)
-  tail.gpa <- gpagen(larvalMorph$tailcoords, curves = larvalMorph$tail.sliders)
+  head.gpa <- gpagen(larvalMorph$headcoords, curves = larvalMorph$head.sliders, 
+                     print.progress = F)
+  tail.gpa <- gpagen(larvalMorph$tailcoords, curves = larvalMorph$tail.sliders, 
+                     print.progress = F)
   succeed(comb.lm <- combine.subsets(head = head.gpa$coords, tail = tail.gpa$coords, 
           gpa = FALSE, CS.sets = NULL))
   succeed(summary(comb.lm))
@@ -90,8 +97,10 @@ test_that("combine.subsets3.works", {
 
 test_that("combine.subsets4.works", {
   data(larvalMorph) 
-  head.gpa <- gpagen(larvalMorph$headcoords, curves = larvalMorph$head.sliders)
-  tail.gpa <- gpagen(larvalMorph$tailcoords, curves = larvalMorph$tail.sliders)
+  head.gpa <- gpagen(larvalMorph$headcoords, curves = larvalMorph$head.sliders, 
+                     print.progress = F)
+  tail.gpa <- gpagen(larvalMorph$tailcoords, curves = larvalMorph$tail.sliders, 
+                     print.progress = F)
   succeed(comb.lm <- combine.subsets(head = head.gpa, tail = tail.gpa, 
           gpa = TRUE, norm.CS = TRUE))
   succeed(summary(comb.lm))
@@ -99,8 +108,10 @@ test_that("combine.subsets4.works", {
 
 test_that("combine.subsets5.works", {
   data(larvalMorph) 
-  head.gpa <- gpagen(larvalMorph$headcoords, curves = larvalMorph$head.sliders)
-  tail.gpa <- gpagen(larvalMorph$tailcoords, curves = larvalMorph$tail.sliders)
+  head.gpa <- gpagen(larvalMorph$headcoords, curves = larvalMorph$head.sliders, 
+                     print.progress = F)
+  tail.gpa <- gpagen(larvalMorph$tailcoords, curves = larvalMorph$tail.sliders, 
+                     print.progress = F)
   succeed(comb.lm <- combine.subsets(head = head.gpa, 
          tail = tail.gpa, gpa = TRUE, norm.CS = FALSE, weights = c(0.3, 0.7)))
   succeed(summary(comb.lm))
@@ -110,30 +121,32 @@ test_that("combine.subsets5.works", {
 
 test_that("compareCR1.works", {
   data(pupfish) 
-  Y.gpa<-gpagen(pupfish$coords)   
+  Y.gpa<-gpagen(pupfish$coords, print.progress = F)   
   land.gps<-rep('a',56); land.gps[39:48]<-'b'
   group <- factor(paste(pupfish$Pop, pupfish$Sex, sep = "."))
   coords.gp <- coords.subset(Y.gpa$coords, group)
   succeed(modul.tests <- Map(function(x) modularity.test(x, land.gps,iter=3, 
-           print.progress = FALSE), coords.gp)) 
+               opt.rot = FALSE, print.progress = FALSE), coords.gp)) 
   succeed(group.Z <- compare.CR(modul.tests, CR.null = FALSE))
   succeed(summary(group.Z))
 })
 
 test_that("compareCR2.works", {
   data(pupfish) 
-  Y.gpa<-gpagen(pupfish$coords)   
+  Y.gpa<-gpagen(pupfish$coords, print.progress = F)   
   land.gps<-rep('a',56); land.gps[39:48]<-'b'
   group <- factor(paste(pupfish$Pop, pupfish$Sex, sep = "."))
   coords.gp <- coords.subset(Y.gpa$coords, group)
   modul.tests <- Map(function(x) modularity.test(x, land.gps,iter=3, 
-            print.progress = FALSE), coords.gp)
+            opt.rot = FALSE, print.progress = FALSE), coords.gp)
   land.gps3 <- rep('a',56); land.gps3[39:48]<-'b'
   land.gps3[c(6:9,28:38)] <- 'c' 
   land.gps4 <- rep('a',56); land.gps4[39:48]<-'b'
   land.gps4[c(6:9,28:38)] <- 'c'; land.gps4[c(10,49:56)] <- 'd'  
-  m3.test <- modularity.test(coords.gp$Marsh.F,land.gps3, iter = 3, print.progress = FALSE)
-  m4.test <- modularity.test(coords.gp$Marsh.F,land.gps4, iter = 3, print.progress = FALSE)
+  m3.test <- modularity.test(coords.gp$Marsh.F,land.gps3, iter = 3, opt.rot = FALSE, 
+                             print.progress = FALSE)
+  m4.test <- modularity.test(coords.gp$Marsh.F,land.gps4, iter = 3, opt.rot = FALSE, 
+                             print.progress = FALSE)
   succeed(model.Z <- compare.CR(modul.tests$Marsh.F,m3.test,m4.test, CR.null = TRUE))
   succeed(summary(model.Z))
 })
@@ -142,11 +155,11 @@ test_that("compareCR2.works", {
 
 test_that("compare.evol.rates1.works", {
   data(plethspecies) 
-  Y.gpa <- gpagen(plethspecies$land)    
+  Y.gpa <- gpagen(plethspecies$land, print.progress = F)    
   gp.end <- factor(c(0,0,1,0,0,1,1,0,0))  
   names(gp.end) <- plethspecies$phy$tip
   succeed(ER<-compare.evol.rates(A = Y.gpa$coords, phy = plethspecies$phy,
-          method = "simulation", iter = 3, gp = gp.end))
+          method = "simulation", iter = 3, gp = gp.end, print.progress = F))
   succeed(summary(ER))
 })
 
@@ -154,10 +167,10 @@ test_that("compare.evol.rates1.works", {
 
 test_that("compare.evol.rates1.works", {
   data(plethspecies) 
-  Y.gpa <- gpagen(plethspecies$land)   
+  Y.gpa <- gpagen(plethspecies$land, print.progress = F)   
   land.gp <- c("A","A","A","A","A","B","B","B","B","B","B")
   succeed(EMR <- compare.multi.evol.rates(A = Y.gpa$coords, gp = land.gp, 
-           Subset = TRUE, phy = plethspecies$phy))
+           Subset = TRUE, phy = plethspecies$phy, iter = 3, print.progress = F))
   succeed(summary(EMR))
 })
 
@@ -165,13 +178,13 @@ test_that("compare.evol.rates1.works", {
 
 test_that("compare.physignal1.works", {
   data(plethspecies) 
-  Y.gpa <- gpagen(plethspecies$land)
+  Y.gpa <- gpagen(plethspecies$land, print.progress = F)
   jaw <- 1:5
   cranium <- 6:11
   PS.jaw <- physignal.z(A = Y.gpa$coords[jaw,,], phy = plethspecies$phy, 
-                        lambda = "front", PAC.no = 7, iter=3)
+                        lambda = "front", PAC.no = 7, iter=3, print.progress = F)
   PS.cranium <- physignal.z(A = Y.gpa$coords[cranium,,], phy = plethspecies$phy, 
-                            lambda = "front", PAC.no = 7, iter=3)
+                            lambda = "front", PAC.no = 7, iter=3, print.progress = F)
   PS.list <-list(PS.jaw, PS.cranium)
   names(PS.list) <- c("jaw", "cranium")
   
@@ -200,7 +213,7 @@ test_that("compare.pls1.works", {
 
 test_that("compare.ZVrel1.works", {
   data("plethodon")
-  Y.gpa <- gpagen(plethodon$land)
+  Y.gpa <- gpagen(plethodon$land, print.progress = F)
   coords.gp <- coords.subset(Y.gpa$coords, plethodon$species)
   Vrel.gp <- Map(function(x) integration.Vrel(x), coords.gp) 
   succeed(out <- compare.ZVrel(Vrel.gp$Jord, Vrel.gp$Teyah))
@@ -242,7 +255,7 @@ test_that("fixed.angle1.works", {
   newLM1 <- fixed.angle(plethspecies$land,
     art.pt = 1, angle.pts.1 = 5, 
     angle.pts.2 = 6, rot.pts = c(2,3,4,5))
-  succeed(Y.gpa1 <- gpagen(newLM1))
+  succeed(Y.gpa1 <- gpagen(newLM1, print.progress = F))
   succeed(plot(Y.gpa1, mean = FALSE))
 })
 
@@ -252,7 +265,7 @@ test_that("fixed.angle2.works", {
     angle.pts.1 = c(1, 6:11), 
     angle.pts.2 = 2:5, 
     rot.pts = NULL, angle = 20, degrees = TRUE) 
-  succeed(Y.gpa2 <- gpagen(newLM2))
+  succeed(Y.gpa2 <- gpagen(newLM2, print.progress = F))
   succeed(plot(Y.gpa2, mean = FALSE))
 })
 
@@ -267,7 +280,7 @@ test_that("fixed.angle1.works", {
 
 test_that("fixed.angle2.works", {
   data(plethodon) 
-  Y.gpa <- gpagen(plethodon$land, PrinAxes = FALSE)
+  Y.gpa <- gpagen(plethodon$land, PrinAxes = FALSE, print.progress = F)
   succeed(gdf <- geomorph.data.frame(Y.gpa, species = plethodon$species, 
       site = plethodon$site))
   succeed(attributes(gdf))
@@ -277,7 +290,7 @@ test_that("fixed.angle2.works", {
 
 test_that("global.integration1.works", {
   data(plethodon) 
-  Y.gpa <- gpagen(plethodon$land)
+  Y.gpa <- gpagen(plethodon$land, print.progress = F)
   succeed(res <- globalIntegration(Y.gpa$coords))
   succeed(summary(res))
 })
@@ -291,7 +304,7 @@ test_that("gm.measurement.error1.works", {
   rep2 <- matrix(fishy$coords[61,], 11, 2, byrow = TRUE)
   succeed(ME1 <- gm.measurement.error(coords = "coordsarray",
     subjects = "subj", replicates = "reps", data = fishy, turbo = FALSE, 
-    iter = 3))
+    iter = 3, print.progress = F))
   succeed(anova(ME1))
   succeed(ICCstats(ME1, subjects = "Subjects", with_in = "Systematic ME"))
   succeed(plot(ME1))
@@ -304,7 +317,7 @@ test_that("gm.measurement.error2.works", {
   rep2 <- matrix(fishy$coords[61,], 11, 2, byrow = TRUE)
   succeed(ME2 <- gm.measurement.error(coords = "coordsarray", subjects = "subj", 
     replicates = "reps", groups = "groups", data = fishy, turbo = FALSE, 
-    iter = 3))
+    iter = 3, print.progress = F))
   succeed(anova(ME2))
   succeed(ICCstats(ME2, subjects = "Subjects", 
       with_in = "Systematic ME", groups = "groups"))
@@ -318,7 +331,7 @@ test_that("gm.measurement.error2.works", {
 
 test_that("gm.prcomp1.works", {
   data(plethspecies) 
-  Y.gpa <- gpagen(plethspecies$land)
+  Y.gpa <- gpagen(plethspecies$land, print.progress = F)
   succeed(PCA <- gm.prcomp(Y.gpa$coords))
   succeed(summary(PCA))
   succeed(plot(PCA, main = "PCA"))
@@ -328,7 +341,7 @@ test_that("gm.prcomp1.works", {
 
 test_that("gm.prcomp2.works", {
   data(plethspecies) 
-  Y.gpa <- gpagen(plethspecies$land)
+  Y.gpa <- gpagen(plethspecies$land, print.progress = F)
   succeed(PCA.w.phylo <- gm.prcomp(Y.gpa$coords, phy = plethspecies$phy))
   succeed(summary(PCA.w.phylo))
   succeed(plot(PCA.w.phylo, phylo = TRUE, main = "PCA.w.phylo"))
@@ -336,7 +349,7 @@ test_that("gm.prcomp2.works", {
 
 test_that("gm.prcomp3.works", {
   data(plethspecies) 
-  Y.gpa <- gpagen(plethspecies$land)
+  Y.gpa <- gpagen(plethspecies$land, print.progress = F)
   succeed(phylo.PCA <- gm.prcomp(Y.gpa$coords, phy = plethspecies$phy, GLS = TRUE))
   succeed(summary(phylo.PCA))
   succeed(plot(phylo.PCA, phylo = TRUE, main = "phylo PCA"))
@@ -344,7 +357,7 @@ test_that("gm.prcomp3.works", {
 
 test_that("gm.prcomp4.works", {
   data(plethspecies) 
-  Y.gpa <- gpagen(plethspecies$land)
+  Y.gpa <- gpagen(plethspecies$land, print.progress = F)
   succeed(phylo.tPCA <- gm.prcomp(Y.gpa$coords, phy = plethspecies$phy, 
     GLS = TRUE, transform = TRUE))
   succeed(summary(phylo.tPCA))
@@ -353,7 +366,7 @@ test_that("gm.prcomp4.works", {
 
 test_that("gm.prcomp5.works", {
   data(plethspecies) 
-  Y.gpa <- gpagen(plethspecies$land)
+  Y.gpa <- gpagen(plethspecies$land, print.progress = F)
   succeed(PaCA.ols <- gm.prcomp(Y.gpa$coords, phy = plethspecies$phy, 
       align.to.phy = TRUE))
   succeed(summary(PaCA.ols))
@@ -362,7 +375,7 @@ test_that("gm.prcomp5.works", {
 
 test_that("gm.prcomp6.works", {
   data(plethspecies) 
-  Y.gpa <- gpagen(plethspecies$land)
+  Y.gpa <- gpagen(plethspecies$land, print.progress = F)
   succeed(PaCA.gls <- gm.prcomp(Y.gpa$coords, phy = plethspecies$phy, 
     align.to.phy = TRUE, GLS = TRUE))
   succeed(summary(PaCA.gls))
@@ -371,7 +384,7 @@ test_that("gm.prcomp6.works", {
 
 test_that("gm.prcomp7.works", {
   data(plethspecies) 
-  Y.gpa <- gpagen(plethspecies$land)
+  Y.gpa <- gpagen(plethspecies$land, print.progress = F)
   succeed(PaCA.gls <- gm.prcomp(Y.gpa$coords, phy = plethspecies$phy, 
     align.to.phy = TRUE, GLS = TRUE, transform = TRUE))
   succeed(summary(PaCA.gls))
@@ -381,7 +394,7 @@ test_that("gm.prcomp7.works", {
 
 test_that("gm.prcomp8.works", {
   data(plethspecies) 
-  Y.gpa <- gpagen(plethspecies$land)
+  Y.gpa <- gpagen(plethspecies$land, print.progress = F)
   PaCA.ols <- gm.prcomp(Y.gpa$coords, phy = plethspecies$phy, 
     align.to.phy = TRUE)
   gps <- as.factor(c(rep("gp1", 5), rep("gp2", 4)))
@@ -396,7 +409,7 @@ test_that("gm.prcomp8.works", {
 
 test_that("gpagen1.works", {
   data(plethodon) 
-  succeed(Y.gpa <- gpagen(plethodon$land, PrinAxes = FALSE))
+  succeed(Y.gpa <- gpagen(plethodon$land, PrinAxes = FALSE, print.progress = F))
   succeed(summary(Y.gpa))
   succeed(plot(Y.gpa))
 })
@@ -404,7 +417,7 @@ test_that("gpagen1.works", {
 test_that("gpagen2.works", {
   data(hummingbirds)
   succeed(Y.gpa <- gpagen(hummingbirds$land, curves = hummingbirds$curvepts,
-      ProcD = FALSE))   
+      ProcD = FALSE, print.progress = F))   
   succeed(summary(Y.gpa))
   succeed(plot(Y.gpa))
 })
@@ -412,7 +425,7 @@ test_that("gpagen2.works", {
 test_that("gpagen3.works", {
   data(hummingbirds)
   succeed(Y.gpa <- gpagen(hummingbirds$land, curves = hummingbirds$curvepts,
-                          ProcD = TRUE))   
+                          ProcD = TRUE, print.progress = F))   
   succeed(summary(Y.gpa))
   succeed(plot(Y.gpa))
 })
@@ -420,7 +433,7 @@ test_that("gpagen3.works", {
 test_that("gpagen4.works", {
   data(scallops)
   succeed(Y.gpa <- gpagen(A = scallops$coorddata, curves = scallops$curvslide, 
-    surfaces = scallops$surfslide))
+    surfaces = scallops$surfslide, print.progress = F))
   succeed(summary(Y.gpa))
 })
 
@@ -428,9 +441,10 @@ test_that("gpagen4.works", {
 
 test_that("integration.test1.works", {
   data(plethodon) 
-  Y.gpa <- gpagen(plethodon$land)
+  Y.gpa <- gpagen(plethodon$land, print.progress = F)
   land.gps <- c("A","A","A","A","A","B","B","B","B","B","B","B") 
-  succeed(IT <- integration.test(Y.gpa$coords, partition.gp = land.gps))
+  succeed(IT <- integration.test(Y.gpa$coords, partition.gp = land.gps, 
+                                 iter = 3, print.progress = F))
   succeed(summary(IT))
   succeed(P <- plot(IT))
   succeed(IT$left.pls.vectors)
@@ -440,7 +454,7 @@ test_that("integration.test1.works", {
 
 test_that("integration.Vrel1.works", {
   data(plethodon) 
-  Y.gpa <- gpagen(plethodon$land)     
+  Y.gpa <- gpagen(plethodon$land, print.progress = F)     
   succeed(res <- integration.Vrel(Y.gpa$coords))
   succeed(print(res))
 })
@@ -463,7 +477,8 @@ test_that("modularity.test1.works", {
   data(pupfish) 
   Y.gpa <- gpagen(pupfish$coords, print.progress = FALSE)
   land.gps <- rep('a',56); land.gps[39:48] <- 'b'
-  succeed(MT <- modularity.test(Y.gpa$coords, land.gps, CI = FALSE, iter = 3))
+  succeed(MT <- modularity.test(Y.gpa$coords, land.gps, opt.rot = FALSE, 
+                                CI = FALSE, iter = 3, print.progress = F))
   succeed(summary(MT))
   succeed(plot(MT))
 })
@@ -501,24 +516,24 @@ test_that("morphol.disparity2.works", {
 
 test_that("morphol.disparity3.works", {
   data(plethspecies)
-  Y.gpa <- gpagen(plethspecies$land)
+  Y.gpa <- gpagen(plethspecies$land, print.progress = F)
   gp.end <- factor(c(0,0,1,0,0,1,1,0,0))
   names(gp.end) <- plethspecies$phy$tip
   gdf <- geomorph.data.frame(Y.gpa, phy = plethspecies$phy, 
     gp.end = gp.end)
   pleth.ols <- procD.lm(coords ~ Csize + gp.end, 
-    data = gdf, iter = 3)
+    data = gdf, iter = 3, print.progress = F)
   pleth.pgls <- procD.pgls(coords ~ Csize + gp.end, phy = phy, 
-    data = gdf, iter = 3)
+    data = gdf, iter = 3, print.progress = F)
   succeed(morphol.disparity(f1 = pleth.ols, groups = ~ gp.end, data = gdf, 
-    print.progress = FALSE))
+    print.progress = FALSE, iter = 3))
   succeed(morphol.disparity(f1 = pleth.pgls, groups = ~ gp.end, 
-    transform = FALSE, data = gdf, print.progress = FALSE))
+    transform = FALSE, data = gdf, print.progress = FALSE, iter = 3))
   succeed(morphol.disparity(f1 = pleth.pgls, groups = ~ gp.end,
-    transform = TRUE, data = gdf, print.progress = FALSE))
-  succeed(PW <- pairwise(pleth.ols, groups = gp.end))
+    transform = TRUE, data = gdf, print.progress = FALSE, iter = 3))
+  succeed(PW <- pairwise(pleth.ols, groups = gp.end, print.progress = F))
   succeed(summary(PW, test.type = 'var'))
-  succeed(PW2 <- pairwise(pleth.pgls, groups = gp.end))
+  succeed(PW2 <- pairwise(pleth.pgls, groups = gp.end, print.progress = F))
   succeed(summary(PW2, test.type = 'var'))
 })
 
@@ -526,10 +541,10 @@ test_that("morphol.disparity3.works", {
 
 test_that("phylo.integration1.works", {
   data(plethspecies) 
-  Y.gpa <- gpagen(plethspecies$land)
+  Y.gpa <- gpagen(plethspecies$land, print.progress = F)
   land.gps <- c("A","A","A","A","A","B","B","B","B","B","B") 
   succeed(IT <- phylo.integration(Y.gpa$coords, partition.gp = land.gps,
-    phy = plethspecies$phy, iter = 3))
+    phy = plethspecies$phy, iter = 3, print.progress = F))
   succeed(summary(IT))
   succeed(P <- plot(IT))
 })
@@ -538,10 +553,10 @@ test_that("phylo.integration1.works", {
 
 test_that("phylo.modularity1.works", {
   data(plethspecies) 
-  Y.gpa <- gpagen(plethspecies$land)
+  Y.gpa <- gpagen(plethspecies$land, print.progress = F)
   land.gps <- c("A","A","A","A","A","B","B","B","B","B","B") 
   succeed(MT <- phylo.modularity(Y.gpa$coords, partition.gp = land.gps, 
-    phy = plethspecies$phy, CI = FALSE, iter = 3))
+    phy = plethspecies$phy, CI = FALSE, iter = 3, print.progress = F))
   succeed(summary(MT))
   succeed(plot(MT)) 
 })
@@ -550,9 +565,9 @@ test_that("phylo.modularity1.works", {
 
 test_that("physignal1.works", {
   data(plethspecies) 
-  Y.gpa <- gpagen(plethspecies$land)
+  Y.gpa <- gpagen(plethspecies$land, print.progress = F)
   succeed(PS.shape <- physignal(A = Y.gpa$coords, phy = plethspecies$phy,
-              iter = 3))
+              iter = 3, print.progress = F))
   succeed(summary(PS.shape))
   succeed((PS.shape))
   succeed(plot(PS.shape$PACA, phylo = TRUE))
@@ -564,12 +579,9 @@ test_that("physignal1.works", {
 test_that("physignal.z1.works", {
   skip_on_cran()
   data(plethspecies) 
-  Y.gpa <- gpagen(plethspecies$land)   
+  Y.gpa <- gpagen(plethspecies$land, print.progress = F)   
   succeed(PS.shape <- physignal.z(A = Y.gpa$coords, phy = plethspecies$phy, 
-       lambda = "front", iter = 3))
-  succeed(summary(PS.shape))
-  succeed(PS.shape <- physignal.z(A = Y.gpa$coords, phy = plethspecies$phy, 
-       lambda = "front", PAC.no = 7, iter = 3))
+       lambda = "front", PAC.no = 7, iter = 3, print.progress = F))
   succeed(summary(PS.shape))
   succeed(plot(PS.shape))
   succeed(plot(PS.shape$PACA, phylo = TRUE))
@@ -655,7 +667,7 @@ test_that("plotAllemtry5.works", {
 
 test_that("plotAllSpecimens1.works", {
   data(plethodon) 
-  Y.gpa <- gpagen(plethodon$land)
+  Y.gpa <- gpagen(plethodon$land, print.progress = F)
   succeed(plotAllSpecimens(Y.gpa$coords, links = plethodon$links))
 })
 
@@ -666,7 +678,7 @@ test_that("plotOutliers1.works", {
   newland <- plethodon$land
   newland[c(1,8),,2] <- newland[c(8,1),,2]
   newland[c(3,11),,26] <- newland[c(11,3),,2]
-  Y<- gpagen(newland) 
+  Y<- gpagen(newland, print.progress = F) 
   succeed(out <- plotOutliers(Y$coords))
   succeed(plotOutliers(Y$coords, inspect.outliers = TRUE))
   succeed(plotOutliers(Y$coords, groups = plethodon$species, 
@@ -677,7 +689,7 @@ test_that("plotOutliers1.works", {
 
 test_that("plotRefToTarget1.works", {
   data(plethodon) 
-  Y.gpa <- gpagen(plethodon$land)
+  Y.gpa <- gpagen(plethodon$land, print.progress = F)
   ref <- mshape(Y.gpa$coords)
   succeed(plotRefToTarget(ref, Y.gpa$coords[,,39]))
   succeed(plotRefToTarget(ref, Y.gpa$coords[,,39], mag = 2, 
@@ -686,7 +698,7 @@ test_that("plotRefToTarget1.works", {
 
 test_that("plotRefToTarget2.works", {
   data(plethodon) 
-  Y.gpa <- gpagen(plethodon$land)
+  Y.gpa <- gpagen(plethodon$land, print.progress = F)
   ref <- mshape(Y.gpa$coords)
   succeed(plotRefToTarget(ref, Y.gpa$coords[,,39], method = "vector", mag = 3))
   succeed(plotRefToTarget(ref, Y.gpa$coords[,,39], method = "points", 
@@ -702,7 +714,7 @@ test_that("plotRefToTarget2.works", {
 
 test_that("procD.lm.example1.works", {
   data(plethodon) 
-  Y.gpa <- gpagen(plethodon$land)
+  Y.gpa <- gpagen(plethodon$land, print.progress = F)
   gdf <- geomorph.data.frame(Y.gpa, 
                              site = plethodon$site, 
                              species = plethodon$species) 
@@ -714,7 +726,7 @@ test_that("procD.lm.example1.works", {
 
 test_that("procD.lm.example2.works", {
   data(plethodon) 
-  Y.gpa <- gpagen(plethodon$land)
+  Y.gpa <- gpagen(plethodon$land, print.progress = F)
   gdf <- geomorph.data.frame(Y.gpa, 
                              site = plethodon$site, 
                              species = plethodon$species) 
@@ -731,7 +743,7 @@ test_that("procD.lm.example2.works", {
 
 test_that("procD.lm.example3.works", {
   data(plethodon) 
-  Y.gpa <- gpagen(plethodon$land)
+  Y.gpa <- gpagen(plethodon$land, print.progress = F)
   gdf <- geomorph.data.frame(Y.gpa, 
                              site = plethodon$site, 
                              species = plethodon$species) 
@@ -751,7 +763,7 @@ test_that("procD.lm.example3.works", {
 
 test_that("procD.lm.example4.works", {  
   data(ratland)
-  rat.gpa<-gpagen(ratland)         
+  rat.gpa<-gpagen(ratland, print.progress = F)         
   gdf <- geomorph.data.frame(rat.gpa)  
   succeed(fit <- procD.lm(coords ~ Csize, data = gdf, iter = 3, verbose = TRUE,
                           RRPP = TRUE, print.progress = FALSE))
@@ -791,20 +803,20 @@ test_that("procD.lm.example5.works", {
 
 test_that("procD.pgls.example1.works", {
   data(plethspecies)
-  Y.gpa <- gpagen(plethspecies$land)
+  Y.gpa <- gpagen(plethspecies$land, print.progress = F)
   gdf <- geomorph.data.frame(Y.gpa, phy = plethspecies$phy)
   succeed(pleth.pgls <- procD.pgls(coords ~ Csize, phy = phy, 
-        iter = 3, data = gdf))
+        iter = 3, data = gdf, print.progress = F))
   succeed(anova(pleth.pgls))
   succeed(summary(pleth.pgls))
 })
 
 test_that("procD.pgls.example2.works", {
   data(plethspecies)
-  Y.gpa <- gpagen(plethspecies$land)
+  Y.gpa <- gpagen(plethspecies$land, print.progress = F)
   gdf <- geomorph.data.frame(Y.gpa, phy = plethspecies$phy)
   pleth.pgls <- procD.pgls(coords ~ Csize, phy = phy, 
-                                   iter = 3, data = gdf)
+                                   iter = 3, data = gdf, print.progress = F)
   succeed(predict(pleth.pgls))
   succeed(plot(pleth.pgls, type = "regression", reg.type = "RegScore", 
     predictor = gdf$Csize))
@@ -819,7 +831,7 @@ test_that("procD.pgls.example2.works", {
 
 test_that("rotate.coords1.works", {
   data(plethodon)
-  Y.gpa <- gpagen(plethodon$land)
+  Y.gpa <- gpagen(plethodon$land, print.progress = F)
   succeed(Y.gpa2 <- rotate.coords(Y.gpa, "flipX"))
   succeed(plot(Y.gpa2))
   succeed(Y.gpa3 <- rotate.coords(Y.gpa2, "rotateCC"))
@@ -832,7 +844,7 @@ test_that("rotate.coords1.works", {
 
 test_that("shape.predictor1.works", {
   data("plethodon")
-  Y.gpa <- gpagen(plethodon$land)      
+  Y.gpa <- gpagen(plethodon$land, print.progress = F)      
   succeed(preds <- shape.predictor(Y.gpa$coords, x = NULL, Intercept = FALSE, 
     pred1 = -0.1, pred2 = 0.1))
   M <- mshape(Y.gpa$coords)
@@ -842,7 +854,7 @@ test_that("shape.predictor1.works", {
 
 test_that("shape.predictor2.works", {
   data("plethodon")
-  Y.gpa <- gpagen(plethodon$land)     
+  Y.gpa <- gpagen(plethodon$land, print.progress = F)     
   M <- mshape(Y.gpa$coords)
   PCA <- gm.prcomp(Y.gpa$coords)
   PC <- PCA$x[,1]
@@ -860,7 +872,7 @@ test_that("shape.predictor2.works", {
 
 test_that("shape.predictor3.works", {
   data("plethodon")
-  Y.gpa <- gpagen(plethodon$land)   
+  Y.gpa <- gpagen(plethodon$land, print.progress = F)   
   M <- mshape(Y.gpa$coords)
   succeed(preds <- shape.predictor(Y.gpa$coords, x = log(Y.gpa$Csize), 
     Intercept = TRUE,  predmin = min(log(Y.gpa$Csize)), 
@@ -871,10 +883,11 @@ test_that("shape.predictor3.works", {
 
 test_that("shape.predictor4.works", {
   data("plethodon")
-  Y.gpa <- gpagen(plethodon$land) 
+  Y.gpa <- gpagen(plethodon$land, print.progress = F) 
   M <- mshape(Y.gpa$coords)
   gdf <- geomorph.data.frame(Y.gpa)
-  plethAllometry <- procD.lm(coords ~ log(Csize), iter = 3, data = gdf)
+  plethAllometry <- procD.lm(coords ~ log(Csize), iter = 3, data = gdf, 
+                             print.progress = F)
   allom.plot <- plot(plethAllometry, type = "regression", 
     predictor = log(gdf$Csize), reg.type ="RegScore") 
   succeed(preds <- shape.predictor(plethAllometry$GM$fitted, 
@@ -893,11 +906,11 @@ test_that("shape.predictor4.works", {
 
 test_that("shape.predictor5.works", {
   data("plethodon")
-  Y.gpa <- gpagen(plethodon$land) 
+  Y.gpa <- gpagen(plethodon$land, print.progress = F) 
   M <- mshape(Y.gpa$coords)
   gdf <- geomorph.data.frame(Y.gpa, species = plethodon$species, 
             site = plethodon$site)
-  pleth <- procD.lm(coords ~ species * site, data=gdf, iter = 3)
+  pleth <- procD.lm(coords ~ species * site, data=gdf, iter = 3, print.progress = F)
   PCA <- prcomp(pleth$fitted)
   means <- unique(round(PCA$x, 3))
   succeed(preds <- shape.predictor(arrayspecs(pleth$fitted, 12,2), x = PCA$x[,1:3],
@@ -911,11 +924,11 @@ test_that("shape.predictor5.works", {
 
 test_that("shape.predictor6.works", {
   data("plethodon")
-  Y.gpa <- gpagen(plethodon$land) 
+  Y.gpa <- gpagen(plethodon$land, print.progress = F) 
   M <- mshape(Y.gpa$coords)
   gdf <- geomorph.data.frame(Y.gpa, species = plethodon$species, 
                              site = plethodon$site)
-  pleth <- procD.lm(coords ~ species * site, data=gdf, iter = 3)
+  pleth <- procD.lm(coords ~ species * site, data=gdf, iter = 3, print.progress = F)
   X <- pleth$X
   X <- X[,-1]
   symJord <- c(0,1,0) 
@@ -928,8 +941,9 @@ test_that("shape.predictor6.works", {
 
 test_that("shape.predictor7.works", {
   data(plethShapeFood) 
-  Y.gpa <- gpagen(plethShapeFood$land)
-  PLS <- two.b.pls(A1 = plethShapeFood$food, A2 = Y.gpa$coords, iter = 3) 
+  Y.gpa <- gpagen(plethShapeFood$land, print.progress = F)
+  PLS <- two.b.pls(A1 = plethShapeFood$food, A2 = Y.gpa$coords, iter = 3, 
+                   print.progress = F) 
   succeed(preds <- shape.predictor(Y.gpa$coords, plethShapeFood$food, 
     Intercept = FALSE,  method = "PLS", 
     pred1 = 2, pred2 = -4, pred3 = 2.5)) 
@@ -961,7 +975,7 @@ test_that("shapeHulls1.works", {
 
 test_that("shapeHulls2.works", {
   data(plethspecies) 
-  Y.gpa <- gpagen(plethspecies$land)    #GPA-alignment
+  Y.gpa <- gpagen(plethspecies$land, print.progress = F)    #GPA-alignment
   pleth.phylo <- gm.prcomp(Y.gpa$coords, phy = plethspecies$phy)
   summary(pleth.phylo)
   succeed(pc.plot <- plot(pleth.phylo, phylo = TRUE))
@@ -974,8 +988,9 @@ test_that("shapeHulls2.works", {
 
 test_that("two.b.pls1.works", {
   data(plethShapeFood) 
-  Y.gpa <- gpagen(plethShapeFood$land)  
-  succeed(PLS <- two.b.pls(Y.gpa$coords, plethShapeFood$food, iter = 3))
+  Y.gpa <- gpagen(plethShapeFood$land, print.progress = F)  
+  succeed(PLS <- two.b.pls(Y.gpa$coords, plethShapeFood$food, iter = 3, 
+                           print.progress = F))
   succeed(summary(PLS))
   succeed(P <- plot(PLS))
 })
@@ -991,26 +1006,28 @@ test_that("two.d.array1.works", {
 
 test_that("physignal.eigen.works", {
   data(plethspecies) 
-  Y.gpa <- gpagen(plethspecies$land)
-  succeed(PSe.shape <- physignal.eigen(Y = Y.gpa$coords, phy = plethspecies$phy))
+  Y.gpa <- gpagen(plethspecies$land, print.progress = F)
+  succeed(PSe.shape <- physignal.eigen(Y = Y.gpa$coords, phy = plethspecies$phy,
+                                       iter = 3))
   succeed(summary(PSe.shape))
   succeed(plot(PSe.shape))
 })
 
 ### extended.pgls --------------------------------------------------------------
 
-test_that("extended.pgls.works", {
-  data(pupfish.ws) 
-  succeed(fit <- extended.pgls(f1 = coords~Species * Sex + Population, 
-                               data = pupfish.ws, species = "Species",
-                               phy = pupfish.ws$phy))
-  succeed(anova(fit))
-  succeed(fit.mult <- manova.update(fit, PC.no = 40))
-  succeed(summary(fit.mult, test = "Wilks"))
-  succeed(fit2 <- extended.pgls(f1 = coords ~ Species * Sex + Population, 
-                                data = pupfish.ws, species = "Species",
-                                Cov = pupfish.ws$Cov))
-  succeed(anova(fit2))
-  succeed(fit2.mult <- manova.update(fit2, PC.no = 40))
-  succeed(summary(fit2.mult, test = "Wilks"))
-})
+#test_that("extended.pgls.works", {
+#  data(pupfish.ws) 
+#  succeed(fit <- extended.pgls(f1 = coords~Species * Sex + Population, 
+#                               data = pupfish.ws, species = "Species",
+#                               phy = pupfish.ws$phy, iter = 3))
+#  succeed(anova(fit))
+#  succeed(fit.mult <- manova.update(fit, PC.no = 40))
+#  succeed(summary(fit.mult, test = "Wilks"))
+#  succeed(fit2 <- extended.pgls(f1 = coords ~ Species * Sex + Population, 
+#                                data = pupfish.ws, species = "Species",
+#                                Cov = pupfish.ws$Cov, iter = 3))
+#  succeed(anova(fit2))
+#  succeed(fit2.mult <- manova.update(fit2, PC.no = 40))
+#  succeed(summary(fit2.mult, test = "Wilks"))
+#})
+# TOO LONG RUNTIME
\ No newline at end of file
